package Acme::MetaSyntactic::unyil;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-03-01'; # DATE
our $DIST = 'Acme-MetaSyntactic-unyil'; # DIST
our $VERSION = '0.001'; # VERSION

use parent qw(Acme::MetaSyntactic::MultiList);
__PACKAGE__->init;

1;
# ABSTRACT: The Unyil theme

=pod

=encoding UTF-8

=head1 NAME

Acme::MetaSyntactic::unyil - The Unyil theme

=head1 VERSION

This document describes version 0.001 of Acme::MetaSyntactic::unyil (from Perl distribution Acme-MetaSyntactic-unyil), released on 2020-03-01.

=head1 SYNOPSIS

 % perl -MAcme::MetaSyntactic=unyil -le 'print metaname'
 ucrit

 % metasyn unyil | shuf | head -n2
 kinoy
 ogah

=head1 DESCRIPTION

Si Unyil is a 1980's Indonesian children TV series.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-MetaSyntactic-unyil>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-MetaSyntactic-unyil>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-MetaSyntactic-unyil>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<https://en.wikipedia.org/wiki/Si_Unyil>

L<Acme::MetaSyntactic>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
# default
main
# names main
unyil ucrit usro kinoy meilani tina bunbun ableh ogah cuplis endut bariah jontor joni tina tineke
# names extra
raden lurah hansip
